@@ -1,9 +1,22 @@
+"""
+The Proxy implementation.
+"""
+
 class ProxyTypeFactory:
+    """
+    Factory for proxy types.
+    """
+
     @staticmethod
     def make(ff_value, string):
         return {'ff_value': ff_value, 'string': string}
 
 class ProxyType:
+    """
+    Set of possible types of proxy. Proxy type has 2 property -
+       'ff_value' is value of Firefox profile preference,
+       'string' is id of proxy type.
+    """
 
     DIRECT = ProxyTypeFactory.make(0, 'DIRECT')           # Direct connection, no proxy (default on Windows).
     MANUAL = ProxyTypeFactory.make(1, 'MANUAL')           # Manual proxy settings (e.g., for httpProxy).
@@ -11,10 +24,13 @@ class ProxyType:
     RESERVED_1 = ProxyTypeFactory.make(3, 'RESERVED1')    # Never used.
     AUTODETECT = ProxyTypeFactory.make(4, 'AUTODETECT')   # Proxy autodetection (presumably with WPAD).
     SYSTEM = ProxyTypeFactory.make(5, 'SYSTEM')           # Use system settings (default on Linux).
-    UNSPECIFIED = ProxyTypeFactory.make(6, 'UNSPECIFIED')
+    UNSPECIFIED = ProxyTypeFactory.make(6, 'UNSPECIFIED') # Not initialized (for internal use).
 
 
 class Proxy(object):
+    """
+    Proxy contains information about proxy type and necessary proxy settings.
+    """
 
     proxyType = ProxyType.UNSPECIFIED
     autodetect = False
@@ -25,6 +41,12 @@ class Proxy(object):
     sslProxy = ''
 
     def __init__(self, raw=None):
+        """
+        Creates a new Proxy.
+
+        :Args:
+         - raw: raw proxy data. If None, default class values are used.
+        """
         if raw is not None:
             if 'proxyType' in raw and raw['proxyType'] is not None:
                 self.proxy_type = raw['proxyType']
@@ -43,73 +65,136 @@ class Proxy(object):
 
     @property
     def proxy_type(self):
+        """
+        Returns proxy type as `ProxyType`.
+        """
         return self.proxyType
 
     @proxy_type.setter
     def proxy_type(self, value):
-        self._verify_proxy_type_compatilibily(ProxyType.AUTODETECT)
+        """
+        Sets proxy type.
+
+        :Args:
+         - value: Te proxy type.
+        """
+        self._verify_proxy_type_compatilibily(value)
         self.proxyType = value
 
     @property
     def auto_detect(self):
+        """
+        Returns autodect setting.
+        """
         return self.autodetect
 
     @auto_detect.setter
     def auto_detect(self, value):
+        """
+        Sets autodetect setting.
+
+        :Args:
+         - value: The autodetect value.
+        """
         if isinstance(value, bool):
             if self.autodetect is not value:
                 self._verify_proxy_type_compatilibily(ProxyType.AUTODETECT)
                 self.proxyType = ProxyType.AUTODETECT
                 self.autodetect = value
         else:
-            raise ValueError("value needs to be a boolean")
+            raise ValueError("Autodetect proxy value needs to be a boolean")
 
     @property
     def ftp_proxy(self):
+        """
+        Returns ftp proxy setting.
+        """
         return self.ftpProxy
 
     @ftp_proxy.setter
     def ftp_proxy(self, value):
+        """
+        Sets ftp proxy setting.
+
+        :Args:
+         - value: The ftp proxy value.
+        """
         self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.ftpProxy = value
 
     @property
     def http_proxy(self):
+        """
+        Returns http proxy setting.
+        """
         return self.httpProxy
 
     @http_proxy.setter
     def http_proxy(self, value):
+        """
+        Sets http proxy setting.
+
+        :Args:
+         - value: The http proxy value.
+        """
         self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.httpProxy = value
 
     @property
     def no_proxy(self):
+        """
+        Returns noproxy setting.
+        """
         return self.noProxy
 
     @no_proxy.setter
     def no_proxy(self, value):
+        """
+        Sets noproxy setting.
+
+        :Args:
+         - value: The noproxy value.
+        """
         self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.noProxy = value
 
     @property
     def proxy_autoconfig_url(self):
+        """
+        Returns proxy autoconfig url setting.
+        """
         return self.proxyAutoconfigUrl
 
     @proxy_autoconfig_url.setter
     def proxy_autoconfig_url(self, value):
+        """
+        Sets proxy autoconfig url setting.
+
+        :Args:
+         - value: The proxy autoconfig url value.
+        """
         self._verify_proxy_type_compatilibily(ProxyType.PAC)
         self.proxyType = ProxyType.PAC
         self.proxyAutoconfigUrl = value
 
     @property
     def ssl_proxy(self):
+        """
+        Returns https proxy setting.
+        """
         return self.sslProxy
 
     @ssl_proxy.setter
     def ssl_proxy(self, value):
+        """
+        Sets https proxy setting.
+
+        :Args:
+         - value: The https proxy value.
+        """
         self._verify_proxy_type_compatilibily(ProxyType.MANUAL)
         self.proxyType = ProxyType.MANUAL
         self.sslProxy = value
@@ -121,6 +206,12 @@ class Proxy(object):
 
 
     def add_to_capabilities(self, capabilities):
+        """
+        Adds proxy information as capability in specified capabilties.
+
+        :Args:
+         - capabilities: The capabilities to which proxy will be added.
+        """
         proxy_caps = {}
         proxy_caps['proxyType'] = self.proxyType['string']
         if self.autodetect:
@@ -133,4 +224,6 @@ class Proxy(object):
             proxy_caps['proxyAutoconfigUrl'] = self.proxyAutoconfigUrl
         if self.sslProxy:
             proxy_caps['sslProxy'] = self.sslProxy
+        if self.noProxy:
+            proxy_caps['noProxy'] = self.noProxy
         capabilities['proxy'] = proxy_caps
